%define major		11
%define libname		%mklibname %{name} %{major}
%define olddevel	%libname-devel
%define libnamedevel	%mklibname %{name} -d
%define tarballver	%(echo %version|sed -e 's/\\./-/g')

Name:		vigra
Version:	1.11.1
Release:	%mkrel 7
Summary:	Generic Programming for Computer Vision
License:	MIT
Group:		System/Libraries
URL:		http://ukoethe.github.io/vigra/
Source0:	https://github.com/ukoethe/vigra/releases/download/Version-%{tarballver}/%{name}-%{version}-src.tar.xz
Patch0:		vigra-1.11.1-gcc8.patch
Patch1:		vigra-1.11.1.py37.patch
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	boost-devel
BuildRequires:	hdf5-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(fftw3) >= 3
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	python3-numpy-devel
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-nose
BuildRequires:	python3-sphinx

%description
VIGRA stands for "Vision with Generic Algorithms". It's a novel computer vision
library that puts its main emphasis on customizable algorithms and data
structures. By using template techniques similar to those in the C++ Standard
Template Library, you can easily adapt any VIGRA component to the needs of your
application without thereby giving up execution speed.

%package devel
Summary:	Development tools for programs which will use the vigra library
Group:		Development/Libraries
Requires:	%{name} = %{version}
Requires:	python3-sphinx
Requires:	python3-numpy-devel

%description devel
The %{libnamedevel} package includes the header files necessary for developing
programs that use the %{name} library.

%package -n	python3-%{name}
Summary:	Python 3 interface for the vigra computer vision library
Group:		Development/Python
%{?python_provide:%python_provide python3-%{name}}
Requires:	python3-numpy
Obsoletes:	%{name}-python
Provides:	%{name}-python = %{version}-%{release}
Obsoletes:	python-%{name}
Provides:	python-%{name} = %{version}-%{release}

%description -n	python3-%{name}
The python3-%{name} package provides python 3 bindings for %{name}.

%prep
%setup -q
%apply_patches

# cleanup
rm -f doc/vigranumpy/.buildinfo

# python shebang
sed -i '1s=^#!/usr/bin/\(python\|env python\)[0-9.]*=#!%{__python3}=' config/vigra-config.in

%build
%cmake \
	-DDOCINSTALL=share/doc/%{name} \
	-DPYTHON_VERSION=%{python3_version} \
	-DWITH_OPENEXR=ON
%cmake_build -j4

%install
%cmake_install

%files
%{_libdir}/lib%{name}impex.so.%{major}
%{_libdir}/lib%{name}impex.so.%{major}.*

%files devel
%doc %{_datadir}/doc/%{name}
%{_bindir}/%{name}-config
%{_includedir}/%{name}/
%{_libdir}/lib%{name}impex.so
%{_libdir}/%{name}/
%{_libdir}/vigranumpy/

%files -n python3-%{name}
%{python3_sitearch}/%{name}/


%changelog
* Sun Sep 18 2022 tex - 1.11.1-7pclos2022
- rebuild against updates

* Wed Jun 29 2022 TerryN <terryn94 at gmail.com> 1.11.1-6pclos2022
- rebuild for python 3.10

* Thu Sep 09 2021 tex - 1.11.1-5pclos2021
- rebuild for boost 1.77.0
